@@ -9,16 +9,29 @@ async def post(path, data=None,
                base_url=tornado.options.options.data_server,
                result_type="json", pack=False, **kwargs):
     async with aiohttp.ClientSession() as session:
-        async with session.post(base_url + path, json=data, **kwargs) as resp:
-            if result_type == "json":
-                result = await resp.json()
-                if not pack:
-                    result = result.get("data")
-            elif result_type == "text":
-                result = await resp.text()
-            else:
-                result = await resp.content.read()
-            return result
+        flag = kwargs.pop("flag", True)
+        if flag:
+            async with session.post(base_url + path, json=data, **kwargs) as resp:
+                if result_type == "json":
+                    result = await resp.json()
+                    if not pack:
+                        result = result.get("data")
+                elif result_type == "text":
+                    result = await resp.text()
+                else:
+                    result = await resp.content.read()
+                return result
+        else:
+            async with session.post(base_url + path, data=data, **kwargs) as resp:
+                if result_type == "json":
+                    result = await resp.json()
+                    if not pack:
+                        result = result.get("data")
+                elif result_type == "text":
+                    result = await resp.text()
+                else:
+                    result = await resp.content.read()
+                return result
 
 
 async def get(path, params=None, base_url=tornado.options.options.data_server, result_type="json", pack=False,
@@ -52,7 +65,11 @@ def sync_get(path, params=None, base_url=tornado.options.options.data_server, re
 def sync_post(path, data=None,
               base_url=tornado.options.options.data_server,
               result_type="json", pack=False, **kwargs):
-    res = requests.post(base_url + path, json=data, **kwargs)
+    flag = kwargs.pop("flag", True)
+    if flag:
+        res = requests.post(base_url + path, json=data, **kwargs)
+    else:
+        res = requests.post(base_url + path, data=data, **kwargs)
     if result_type == "json":
         res = res.json()
         if not pack:
