@@ -207,7 +207,10 @@ class BaseHandler(RequestHandler):
             if user_info and isinstance(user_info, dict):
                 user = User()
                 for key in user_info:
+                    if key == "roleIds" and user_info[key] and isinstance(user_info[key], str):
+                        user_info[key] = json.loads(user_info[key])
                     setattr(user, key, user_info[key])
+
                 return user
         return None
 
