@@ -11,6 +11,7 @@ from requests import post, get
 from tornado.web import RequestHandler
 
 from lesscode.db.redis.redis_helper import RedisHelper
+from lesscode.utils.doc.interface_doc_handler import parser_swagger
 from lesscode.web.business_exception import BusinessException
 from lesscode.web.status_code import StatusCode
 from tornado.options import define
@@ -43,7 +44,7 @@ class RouterMapping(list):
         return RouterMapping._instance
 
 
-def Handler(url: str):
+def Handler(url: str, desc=""):
     """
     RequestHandler对应路径注册装饰器，完成处理类与url对应注册。
     :param prefix: 路由前缀
@@ -83,7 +84,7 @@ def Handler(url: str):
                          json={"client_name": client_name})
                     client_res = get(url=f"{tornado.options.options.rms_register_server}/upms/client/fetchall",
                                      params={"client_name": client_name}).json()
-                client_id = client_res.get("data")[0].get("client_id")
+                client_id = client_res.get("data")[0].get("id")
                 resource_res = get(
                     url=f"{tornado.options.options.rms_register_server}/upms/resource/fetchall",
                     params={"client_name": client_name, "resource_type": 2, "url": full_url}).json()
@@ -96,6 +97,11 @@ def Handler(url: str):
                     else:
                         print(f"add url={full_url} to rms fail")
         cls.__route_name__ = url
+        try:
+            parser_swagger(cls, desc)
+        except:
+            pass
+
         return cls
 
     return wrapper
@@ -121,6 +127,10 @@ def GetMapping(url: str = "", client_name: str = None, title: str = None, en_nam
             (func.__qualname__.replace('.' + func.__name__, ''), func, path, client_name, title, en_name, access))
         func.__route_name__ = path
         func.__http_method__ = "get"
+        try:
+            parser_swagger(func, title)
+        except:
+            pass
         return func
 
     return wrapper
@@ -146,6 +156,11 @@ def PostMapping(url: str = "", client_name: str = None, title: str = None, en_na
             (func.__qualname__.replace('.' + func.__name__, ''), func, path, client_name, title, en_name, access))
         func.__route_name__ = path
         func.__http_method__ = "post"
+        try:
+            parser_swagger(func, title)
+        except:
+            pass
+
         return func
 
     return wrapper
